sw/qa/extras/ooxmlexport/ooxmlexport9.cxx |   16 ++++++++++++----
 1 file changed, 12 insertions(+), 4 deletions(-)

New commits:
commit 8bc607225e6bc9ba343e2292f9185b6491108e44
Author:     Miklos Vajna <vmik...@collabora.com>
AuthorDate: Tue Mar 21 08:17:46 2023 +0100
Commit:     Miklos Vajna <vmik...@collabora.com>
CommitDate: Tue Mar 21 08:17:28 2023 +0000

    sw floattable, CppunitTest_sw_ooxmlexport9: assert the layout in 
testTdf107889
    
    The point is that the table is multi-page, which is preserved. The
    detail that it's not in a fly is no longer true.
    
    Change-Id: I63ee8182638a2f0118584f5e985abaf1c3d7e337
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/149188
    Reviewed-by: Miklos Vajna <vmik...@collabora.com>
    Tested-by: Jenkins

diff --git a/sw/qa/extras/ooxmlexport/ooxmlexport9.cxx 
b/sw/qa/extras/ooxmlexport/ooxmlexport9.cxx
index 9013dc83c126..da430214d75f 100644
--- a/sw/qa/extras/ooxmlexport/ooxmlexport9.cxx
+++ b/sw/qa/extras/ooxmlexport/ooxmlexport9.cxx
@@ -1156,10 +1156,18 @@ DECLARE_OOXMLEXPORT_TEST(testTdf107033, 
"tdf107033.docx")
 }
 
 #if HAVE_MORE_FONTS
-DECLARE_OOXMLEXPORT_TEST(testTdf107889, "tdf107889.docx")
-{
-    // This was 1, multi-page table was imported as a floating one.
-    CPPUNIT_ASSERT_EQUAL(0, getShapes());
+CPPUNIT_TEST_FIXTURE(Test, testTdf107889)
+{
+    SwModelTestBase::FlySplitGuard aGuard;
+    auto verify = [this]() {
+        // This was 1, multi-page table was imported as a non-split fly.
+        xmlDocUniquePtr pXmlDoc = parseLayoutDump();
+        assertXPath(pXmlDoc, "//tab", 2);
+    };
+    createSwDoc("tdf107889.docx");
+    verify();
+    reload(mpFilter, "tdf107889.docx");
+    verify();
 }
 #endif
 

Reply via email to